@@ -1,7 +1,6 @@
-import json
 import yaml
 
-from pkg_resources import resource_string, resource_stream
+from pkg_resources import resource_stream
 
 # parameters in number of nibbles (based on string representations of SIP bytes), total lengths in number of SIP bytes
 
